@@ -11,6 +11,7 @@ from .ess_client import EssClient
 from .vpc_client import VpcClient
 from .cs_client import CsClient
 from .r_kvstore_client import RKvstoreClient
+from .waf_client import WAFClient
 
 prod_mapper = {
     'cdn': CdnClient,
@@ -24,6 +25,7 @@ prod_mapper = {
     'cs': CsClient,
     'nat': NatClient,
     'r-kvstore': RKvstoreClient,
+    'semawaf': WAFClient
 }
 
 
@@ -86,4 +88,8 @@ def nat_client():
 
 @proxy
 def rkv_client():
-    return get_current_client('r-kvstore')
\ No newline at end of file
+    return get_current_client('r-kvstore')
+
+@proxy
+def waf_client():
+    return get_current_client('semawaf')
\ No newline at end of file
