@@ -342,6 +342,10 @@ class TencentEip:
     def instance_id(self):
         return self.object.get("InstanceId", "")
 
+    @property
+    def charge_type(self):
+        return self.object.get("InternetChargeType", "")
+
     @classmethod
     def list(cls, **kwargs):
         address_set = vpc_client.describe_eip(**kwargs).get('AddressSet')
@@ -364,9 +368,24 @@ class TencentSecurityGroup:
 
     @classmethod
     def list(cls, **kwargs):
-        sgs = vpc_client.describe_sgs(**kwargs).get('SecurityGroupSet')
+        import math
+        kwargs.update(
+            {
+                "Offset": "0",
+                "Limit": "100"
+            }
+        )
+        sg_infos = vpc_client.describe_sgs(**kwargs)
+        sgs = sg_infos.get('SecurityGroupSet')
         if not sgs:
             return
+        if sg_infos.get('TotalCount') > len(sgs):
+            for i in range(math.ceil(sg_infos.get('TotalCount') / 100) - 1):
+                kwargs.update({
+                    "Offset": str(100*(i+1)),
+                    "Limit": "100"
+                })
+                sgs.extend(vpc_client.describe_sgs(**kwargs).get('SecurityGroupSet'))
         return [cls(sg) for sg in sgs]
 
 
